@@ -6,6 +6,7 @@ no warnings 'uninitialized';
 use Carp;
 use Audio::Nama::Globals qw(:singletons $this_bus $this_track);
 use Audio::Nama::Log qw(logpkg logsub);
+use Data::Dumper::Concise;
 use List::MoreUtils qw(first_index);
 
 sub initialize_prompt {
@@ -44,6 +45,16 @@ sub setup_hotkeys {
 	setup_termkey(); 
 	1
 }
+sub list_hotkeys { 
+	my $hots 		= dclone($config->{hotkeys});
+	my %hots = %$hots;
+	$hots{'='} 		= 'Enter numeric value';
+	$hots{ 'mN' } 	= 'Change step size to 10 raised to the Nth power';
+	$hots{ '#' }	= 'Engage hotkey mode (must be typed in column 1)';
+	pager("Hotkeys\n",Dumper \%hots)
+}
+
+
 sub setup_termkey {
 	$project->{events}->{termkey} = AnyEvent::TermKey->new(
 		term => \*STDIN,
@@ -270,6 +281,7 @@ sub file_pager {
 		return;
     }
 	my $pager = $ENV{PAGER} || "/usr/bin/less";
+	$pager =~ /less/ and $pager .= qq( -M -i -PM"q=quit pager, /=search, PgUp/PgDown=scroll (line %lt/%L)");
 	my $cmd = qq($pager $fname); 
 	system $cmd;
 }
